@@ -32,7 +32,7 @@ import re
 import sys
 import warnings
 
-from . import jsonlayer
+import json
 from .KeyCaseInsensitiveDict import KeyCaseInsensitiveDict
 from .SPARQLExceptions import QueryBadFormed, EndPointNotFound, EndPointInternalError
 from .SPARQLUtils import deprecated
@@ -397,15 +397,15 @@ class SPARQLWrapper(object):
 
     def setUseKeepAlive(self):
         """Make urllib2 use keep-alive.
-        @raise ImportError: when could not be imported urlgrabber.keepalive.HTTPHandler
+        @raise ImportError: when could not be imported keepalive.HTTPHandler
         """
         try:
-            from urlgrabber.keepalive import HTTPHandler
+            from keepalive import HTTPHandler
             keepalive_handler = HTTPHandler()
             opener = urllib.request.build_opener(keepalive_handler)
             urllib.request.install_opener(opener)
         except ImportError:
-            warnings.warn("urlgrabber not installed in the system. The execution of this method has no effect.")
+            warnings.warn("keepalive support not available, so the execution of this method has no effect")
 
     def isSparqlUpdateRequest(self):
         """ Returns TRUE if SPARQLWrapper is configured for executing SPARQL Update request
@@ -507,7 +507,7 @@ class SPARQLWrapper(object):
         if self.user and self.passwd:
             if self.http_auth == BASIC:
                 credentials = "%s:%s" % (self.user, self.passwd)
-                request.add_header("Authorization", "Basic %s" % base64.b64encode(credentials.encode('utf-8')))
+                request.add_header("Authorization", "Basic %s" % base64.b64encode(credentials.encode('utf-8')).decode('utf-8'))
             elif self.http_auth == DIGEST:
                 realm = "SPARQL"
                 pwd_mgr = urllib.request.HTTPPasswordMgr()
@@ -631,20 +631,6 @@ class QueryResult(object):
         """Method for the standard iterator."""
         return next(self.response)
 
-    @staticmethod
-    def setJSONModule(module):
-        """Set the Python module for encoding JSON data. If not an allowed value, the setting is ignored.
-           JSON modules supported:
-             - ``simplejson``: http://code.google.com/p/simplejson/
-             - ``cjson``: http://pypi.python.org/pypi/python-cjson
-             - ``json``: This is the version of ``simplejson`` that is bundled with the
-               Python standard library since version 2.6
-               (see http://docs.python.org/library/json.html)
-        @param module: Possible values: are L{simplejson}, L{cjson}, L{json}. All other cases raise a ValueError exception.
-        @type module: string
-        """
-        jsonlayer.use(module)
-
     def _convertJSON(self):
         """
         Convert a JSON result into a Python dict. This method can be overwritten in a subclass
@@ -652,7 +638,7 @@ class QueryResult(object):
         @return: converted result
         @rtype: Python dictionary
         """
-        return jsonlayer.decode(self.response.read().decode("utf-8"))
+        return json.loads(self.response.read().decode("utf-8"))
 
     def _convertXML(self):
         """
